@@ -38,6 +38,6 @@ test_that("ebirdst_habitat pland_only", {
 })
 
 test_that("plot ebirdst_habitat", {
-  expect_silent({g <- plot(habitat)})
+  suppressWarnings({g <- plot(habitat)})
   expect_is(g, "gg")
 })
